@@ -9,7 +9,7 @@
 # Copyright ©2011-2025. Hunan xxxxxxx Company limited. All rights reserved.
 # ---------------------------------------------------------------------------------------------------------
 """
-from typing import List, Optional
+from typing import List
 from playwright.async_api import Page, Locator, TimeoutError as PlaywrightTimeoutError
 
 
@@ -55,7 +55,7 @@ class BasePo(object):
     async def exists_one(locator):
         return await locator.count() == 1
 
-    async def get_locator(self, selector: str, timeout: float = 3.0) -> Optional[Locator]:
+    async def get_locator(self, selector: str, timeout: float = 3.0) -> Locator:
         """
         获取页面元素locator
         :param selector: 选择器表达式
